@@ -1,4 +1,6 @@
+mod admin;
 mod blocktime;
+mod config;
 mod daemon;
 mod health;
 mod process;
